@@ -1,9 +1,10 @@
 ### R code from vignette source 'german.Rnw'
 
 ###################################################
-### code chunk number 1: german.Rnw:24-25
+### code chunk number 1: german.Rnw:23-25
 ###################################################
 options(prompt = "R> ", continue = " ", width = 70, digits =4, useFancyQuotes = FALSE)
+ptm <- proc.time()
 
 
 ###################################################
@@ -165,3 +166,15 @@ dat <- cbind(dt, tmp)
 ## cat("cross-validated loglik", max(fitcv$cv))
 
 
+###################################################
+### code chunk number 22: german.Rnw:152-153 (eval = FALSE)
+###################################################
+## print(proc.time()-ptm)
+
+
+###################################################
+### code chunk number 23: sessionInfo
+###################################################
+sessionInfo();
+
+
